
Audit logs.
-------

**Description:**

An audit trail (also called audit log) is a security-relevant chronological record, 
set of records, and/or destination and source of records that provide documentary 
evidence of the sequence of activities that have affected at any time a specific operation, 
procedure, or event.


**Solution:**

An audit log should contain the following items:

-User id
-Operation
-Success/failure of the operation
-Privileges
-Timestamp





	